.. _sec_api:

=============
API Reference
=============

Loading and saving Demes graphs
-------------------------------

.. autofunction:: demes.load
.. autofunction:: demes.loads
.. autofunction:: demes.dump
.. autofunction:: demes.dumps

Constructing Demes graphs
-------------------------

.. autoclass:: demes.Builder
   :members:

Examining Demes graphs
---------------------------

.. autoclass:: demes.Graph
    :members:

.. autoclass:: demes.Deme
    :members:

.. autoclass:: demes.Epoch
    :members:

Continuous demographic events
-----------------------------

.. autoclass:: demes.Migration
    :members:

.. autoclass:: demes.AsymmetricMigration
    :members:

.. autoclass:: demes.SymmetricMigration
    :members:

Discrete demographic events
---------------------------

.. autoclass:: demes.Pulse
    :members:

.. autoclass:: demes.Split
    :members:

.. autoclass:: demes.Branch
    :members:

.. autoclass:: demes.Merge
    :members:

.. autoclass:: demes.Admix
    :members:
